pub trait RasterableVol: BaseVol {
const SIZE: Vec3<u32>;
}Expand description
A volume that is compile-time sized and has its lower bound at (0, 0, 0).
The name RasterableVol was chosen because such a volume can be used with
VolGrid3d.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".